from setuptools import setup

setup(name='distrib_probab',
      version='0.1',
      description='Gaussian distributions',
      packages=['distrib_probab'],
      author = 'Stephen G',
      zip_safe=False)
